@@ -138,8 +138,8 @@ pub struct RPCPubKey {
 #[derive(Deserialize, Serialize, Debug)]
 pub struct RPCValidatorUpdate {
     pub pub_key: RPCPubKeyOuter,
-    #[serde(with = "terra_u64_format")]
-    pub power: u64,
+    //   #[serde(with = "terra_u64_format")]
+    //   pub power: u64,
 }
 
 #[derive(Deserialize, Serialize, Debug)]
